@@ -19,13 +19,18 @@
             else
                 tmp
     }
+    chains <- NULL
     if (inherits(comm, "simmat")) {
         x <- comm
         method <- attr(x, "method")
         nsimul <- dim(x)[3]
         if (nsimul == 1)
-            stop("only one simulation in ", sQuote(deparse(substitute(comm))))
+            stop(gettextf("only one simulation in '%s'",
+                          deparse(substitute(comm))))
         comm <- attr(comm, "data")
+        #thin <- attr(comm, "thin")
+        burnin <- attr(x, "start") - attr(x, "thin")
+        chains <- attr(x, "chains")
         simmat_in <- TRUE
     } else {
         simmat_in <- FALSE
@@ -50,7 +55,7 @@
     if (!simmat_in && !is.na(batchsize)) {
         commsize <- object.size(comm)
         totsize <- commsize * nsimul
-        if (totsize > batchsize) { 
+        if (totsize > batchsize) {
             nbatch <- ceiling(unclass(totsize/batchsize))
             batches <- diff(round(seq(0, nsimul, by = nsimul/nbatch)))
         } else {
@@ -61,7 +66,7 @@
     }
     if (nbatch == 1)
         batches <- nsimul
-    
+
     ind <- nestfun(comm, ...)
     indstat <-
         if (is.list(ind))
@@ -72,7 +77,7 @@
     if (!simmat_in && nm$commsim$isSeq) {
         ## estimate thinning for "tswap" (trial swap)
         if (nm$commsim$method == "tswap") {
-            checkbrd <-sum(designdist(comm, "(J-A)*(J-B)", 
+            checkbrd <-sum(designdist(comm, "(J-A)*(J-B)",
                                       "binary"))
             M <- nm$ncol
             N <- nm$nrow
@@ -130,21 +135,29 @@
                                           statistic = statistic, ...))
         }
     }
-    
+
     simind <- matrix(simind, ncol = nsimul)
 
     if (attr(x, "isSeq")) {
         attr(simind, "thin") <- attr(x, "thin")
         attr(simind, "burnin") <- burnin
+        attr(simind, "chains") <- chains
     }
-    
+
     sd <- apply(simind, 1, sd, na.rm = TRUE)
     means <- rowMeans(simind, na.rm = TRUE)
     z <- (indstat - means)/sd
     if (any(sd < sqrt(.Machine$double.eps)))
         z[sd < sqrt(.Machine$double.eps)] <- 0
-    pless <- rowSums(indstat >= simind, na.rm = TRUE)
-    pmore <- rowSums(indstat <= simind, na.rm = TRUE)
+    ## results can be integers or real: comparisons differ
+    if (is.integer(indstat) && is.integer(simind)) {
+        pless <- rowSums(indstat >= simind, na.rm = TRUE)
+        pmore <- rowSums(indstat <= simind, na.rm = TRUE)
+    } else {
+        EPS <- sqrt(.Machine$double.eps)
+        pless <- rowSums(indstat + EPS >= simind, na.rm = TRUE)
+        pmore <- rowSums(indstat - EPS <= simind, na.rm = TRUE)
+    }
     if (any(is.na(simind))) {
         warning("some simulated values were NA and were removed")
         nsimul <- nsimul - rowSums(is.na(simind))
@@ -154,14 +167,22 @@
                 less = pless,
                 greater = pmore)
     p <- pmin(1, (p + 1)/(nsimul + 1))
-    
+
     ## ADDITION: if z is NA then it is not correct to calculate p values
     ## try e.g. oecosimu(dune, sum, "permat")
     if (any(is.na(z)))
         p[is.na(z)] <- NA
 
-    if (is.null(names(indstat)) && length(indstat) == 1)
-        names(indstat) <- statistic
+    ## take care that statistics have name, or some support functions
+    ## can fail
+    if (is.null(names(indstat))) {
+        if (length(indstat) == 1)
+            names(indstat) <- statistic
+        else if (length(indstat) <= length(letters))
+            names(indstat) <- letters[seq_along(indstat)]
+        else
+            names(indstat) <- paste0("stat", seq_along(indstat))
+    }
     oecosimu <- list(z = z, means = means, pval = p, simulated=simind,
                      method=method, statistic = indstat,
                      alternative = alternative, isSeq = attr(x, "isSeq"))
