@@ -1,15 +1,16 @@
 `taxa2dist` <-
-    function (x, varstep = FALSE, check = TRUE, labels) 
+    function (x, varstep = FALSE, check = TRUE, labels)
 {
     rich <- apply(x, 2, function(taxa) length(unique(taxa)))
     S <- nrow(x)
+    ## check drops redundant levels (constant or non-repeating)
     if (check) {
         keep <- rich < S & rich > 1
         rich <- rich[keep]
-        x <- x[, keep]
+        x <- x[, keep, drop=FALSE]
     }
     i <- rev(order(rich))
-    x <- x[, i]
+    x <- x[, i, drop=FALSE]
     rich <- rich[i]
     if (varstep) {
         add <- -diff(c(nrow(x), rich, 1))
@@ -19,9 +20,9 @@
     else {
         add <- rep(100/(ncol(x) + check), ncol(x) + check)
     }
-    if (!is.null(names(add))) 
+    if (!is.null(names(add)))
         names(add) <- c("Base", names(add)[-length(add)])
-    if (!check) 
+    if (!check)
         add <- c(0, add)
     out <- matrix(add[1], nrow(x), nrow(x))
     for (i in 1:ncol(x)) {
@@ -34,10 +35,11 @@
         attr(out, "Labels") <- rownames(x)
     } else {
         if (length(labels) != nrow(x))
-            warning("Labels are wrong: needed ", nrow(x), " got ", length(labels))
+            warning(gettextf("labels are wrong: needed %d, got %d",
+                             nrow(x), length(labels)))
         attr(out, "Labels") <- as.character(labels)
     }
     if (!check && any(out <= 0))
-        warning("you used 'check=FALSE' and some distances are zero -- was this intended?")
+        warning("you used 'check=FALSE' and some distances are zero: was this intended?")
     out
 }
